@@ -19,9 +19,9 @@ except:
 
 from docutils.core import publish_cmdline, default_description
 
-from rstgo.rst import setup_pelican
+from rstgo.rst import setup_docutils
 
-setup_pelican()
+setup_docutils()
 
 description = ('Generates (X)HTML documents from standalone reStructuredText '
                'sources.  ' + default_description)
