@@ -30,16 +30,11 @@ class TileSet(object):
         return self.tile_cache[tile]
 
     def annotate(self, tile, annotation):
+
         if tile == 'black':
             fgcolor = (255, 255, 255)
         else:
             fgcolor = (0, 0, 0)
-        translations = {
-            'triangle': u'\u25be',
-            'square': u'\u25aa',
-            'bullet': u'\u2022',
-        }
-        annotation = translations.get(annotation, str(annotation))
         annotated_tile_name = '-'.join([tile, annotation])
         if annotated_tile_name not in self.tile_cache:
             tile_object = self[tile].copy()
@@ -52,7 +47,15 @@ class TileSet(object):
         return self.tile_cache[annotated_tile_name]
       
     def render_annotation(self, stone, annotation, fgcolor):
-        font = ImageFont.truetype(os.path.join(FONTPATH, 'FreeSans.ttf'), 11)
+        fontsize_mapping = {
+            1: 11,
+            2: 9,
+            3: 8
+        }
+
+        fontsize = fontsize_mapping.get(len(annotation), 11)
+        font = ImageFont.truetype(os.path.join(FONTPATH, 'FreeSans.ttf'), 
+                                  fontsize)
         label = Image.new('RGBA', self.tile_size, (255,255,255,255))
         draw = ImageDraw.Draw(stone) 
         label_size = draw.textsize(annotation, font=font)
@@ -102,22 +105,15 @@ class TileSet(object):
                        (x+1)*self.tile_size[0], (y+1)*self.tile_size[1])
                 image.paste(self[tile], box)
 
-        for i in diagram.sequence:
-            if i % 2:
-                player = diagram.first_player
+        for c in diagram.marked_coordinates:
+            x, y = c
+            box = (x*self.tile_size[0], y*self.tile_size[1],
+                   (x+1)*self.tile_size[0], (y+1)*self.tile_size[1])
+            mark = diagram.marked_coordinates[c]
+            if mark[1]:
+            	tile = self.annotate(mark[0], mark[1])
             else:
-                player = diagram.second_player
-            x, y = diagram.sequence[i]
-            box = (x*self.tile_size[0], y*self.tile_size[1],
-                   (x+1)*self.tile_size[0], (y+1)*self.tile_size[1])
-            tile = self.annotate(player, i)
-            image.paste(tile, box)
-
-        for a in diagram.annotated_points:
-            x, y = diagram.annotated_points[a]
-            box = (x*self.tile_size[0], y*self.tile_size[1],
-                   (x+1)*self.tile_size[0], (y+1)*self.tile_size[1])
-            tile = self.annotate('empty', a)
+                tile = mark[0]
             image.paste(tile, box)
         return image
 
@@ -201,17 +197,15 @@ class GoDiagram(object):
         return cls(board=board,
             initial_black=parser.initial_black,
             initial_white=parser.initial_white,
-            sequence=parser.sequence_moves,
-	    annotated_points=parser.annotated_points,
-	    first_player=parser.first_player,
+            marked_coordinates=parser.marked_coordinates,
+            first_player=parser.first_player,
         )
 
-    def __init__(self, board=Board(), initial_black=None, initial_white=None, sequence=None, annotated_points=None, first_player='black'):
+    def __init__(self, board=Board(), initial_black=None, initial_white=None, marked_coordinates=None, first_player='black'):
         self.board = board
         self.initial_black = initial_black or set()
         self.initial_white = initial_white or set()
-        self.sequence = sequence or {}
-        self.annotated_points = annotated_points or {}
+        self.marked_coordinates = marked_coordinates or {}
         self.first_player = first_player
         if self.first_player == 'black':
             self.second_player = 'white'
@@ -234,8 +228,12 @@ class GoDiagram(object):
 if __name__ == '__main__':
     black_set = set([(4, 4), (4, 5)])
     white_set = set([(3, 2), (7, 3), (8, 3)])
-    sequence = {1: (2, 2), 2: (1,2), 3: (2,3), 4: (3,1)}
-    
+    marked_coordinates = {
+        (2, 2): 1,
+        (1, 2): 2,
+        (2, 3): 3,
+        (3, 1): 4,
+    } 
     board = Board(
         (9, 9), 
     )
